@@ -56,6 +56,7 @@ class UsbTmcDevice(UsbTmcBase):
         super().__init__(**kwargs)
 
         self._opened = False
+        self._reattach_kernel_driver = []
         self._ep_bulk_in = self._ep_bulk_out = self._ep_intr_in = None
         self._timeout_ms = int(timeout*1000) if timeout is not None else UsbTmcBase.DEFAULT_TIMEOUT_MS
         self._address = address
@@ -108,18 +109,20 @@ class UsbTmcDevice(UsbTmcBase):
         if self._interface.bInterfaceProtocol != UsbTmcBase.USB488_INTERFACE_PROTOCOL:
             pass
 
-        self._reattach_kernel_driver = []
+        try:
+            if self._device.is_kernel_driver_active(self._interface.index):
+                self._reattach_kernel_driver.append(self._interface)
 
-        if self._device.is_kernel_driver_active(self._interface.index):
-            self._reattach_kernel_driver.append(self._interface)
-
-            try:
-                self._device.detach_kernel_driver(self._interface.index)
-            except usb.core.USBError as e:
-                raise UsbTmcConnectionException(
-                    f'USB device with VID:PID {self._address.vid:04x}:{self._address.pid:04x}'
-                    + (f' (serial number: {self._address.serial_number})' if self._address.serial_number is not None else '')
-                    + f' could not be detached from kernel driver at interface index {self._interface.index} ({e})') from None
+                try:
+                    self._device.detach_kernel_driver(self._interface.index)
+                except usb.core.USBError as e:
+                    raise UsbTmcConnectionException(
+                        f'USB device with VID:PID {self._address.vid:04x}:{self._address.pid:04x}'
+                        + (f' (serial number: {self._address.serial_number})' if self._address.serial_number is not None else '')
+                        + f' could not be detached from kernel driver at interface index {self._interface.index} ({e})') from None
+        except NotImplementedError:
+            # We are on a platform that does not implement kernel driver detach/attach, just ignore then
+            pass
 
         # set configuration
         try:
@@ -506,6 +509,7 @@ class UsbTmcDevice(UsbTmcBase):
         if not self._opened:
             return
 
+        usb.util.release_interface(self._device, self._interface)
         usb.util.dispose_resources(self._device)
 
         # reattach kernel driver
